bayespy.inference.vmp.nodes.gaussian.GaussianGammaISODistribution.plates_from_parent
====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISODistribution.plates_from_parent